@@ -13,9 +13,13 @@ class Ui:
     from .elements.html import Html as html
     from .elements.label import Label as label
     from .elements.link import Link as link
+    from .elements.log import Log as log
     from .elements.markdown import Markdown as markdown
+    from .elements.menu import Menu as menu
+    from .elements.notify import Notify as notify
     from .elements.number import Number as number
     from .elements.radio import Radio as radio
+    from .elements.scene import Scene as scene
     from .elements.select import Select as select
     from .elements.slider import Slider as slider
     from .elements.svg import Svg as svg
